.. expect: missing underscore after closing backtick in hyperlink
And, as it looks a lot like a default role, it also triggers:
.. expect: default role used


A hyperlink is marked with an underscore after the closing
backtick. Wrong (this is taken as a use of the default role):

`Link text <https://example.com>`
